@@ -332,17 +332,19 @@ class SensiConfig:
         if len(self.param_map)>0:
             # Read settings.json from each sensi dir and apply changes
             for sensi_name, sensi_dirpath in sensi_dirs_to_process.items():
-                log(f"Applying stresses of sensi {sensi_name} in {sensi_dirpath}", self.logger)
+                log(f"Applying {sensi_name} stresses in {sensi_dirpath}", self.logger)
                 if os.path.exists(sensi_dirpath):
                     try:
                         settings_json_sensi = read_json_file(os.path.join(sensi_dirpath, 'resources/settings.json').replace("\\", "/"))
                     except Exception as err:
-                        processed_sensi_messages[sensi_name] = SensiIOError("Unable to read settings.json in {}: {}".format(sensi_name, err))
+                        processed_sensi_messages[sensi_name] = SensiIOError("Unable to read the settings.json in {}".format(sensi_name))
+                        log(f"{processed_sensi_messages[sensi_name].msg}: {str(err)}", self.logger)
                         continue
 
                     if settings_json_sensi is not None:
                         settings_modif_express = list()
                         settings_modif_values = list()
+                        total_applied = 0
                         for stress_name in self.sensi_list[sensi_name]:
                             log(f"Applying stress {stress_name} to {sensi_name}", self.logger)
                             counter = 0
@@ -356,11 +358,11 @@ class SensiConfig:
                                         if applied:
                                             counter += 1
                                             processed_sensi_messages[sensi_name] = "Applied {} modification(s) on input files of {}".format(counter, sensi_name)
-                                            log(processed_sensi_messages[sensi_name], self.logger)
+                                            log("Applied {} with col {}, condition {} and value {} on input file {}".format(syntax.expression, syntax.col, syntax.condition, syntax.value, path_to_file), self.logger)
                                         else:
                                             # print("Failed to apply a syntax to {}".format(path_to_file))
-                                            processed_sensi_messages[sensi_name] = SensiIOError("Failed to apply a modification to {}".format(path_to_file))
-                                            log(processed_sensi_messages[sensi_name].msg, self.logger)
+                                            processed_sensi_messages[sensi_name] = SensiIOError("Failed to apply {} stress on {}".format(sensi_name, Path(path_to_file).name))
+                                            log("Failed to apply {} with col {}, condition {} and value {} on {}".format(syntax.expression, syntax.col, syntax.condition, syntax.value, path_to_file), self.logger)
                                             break
                                     else:
                                         try:
@@ -370,22 +372,31 @@ class SensiConfig:
                                                 expression = "framework.sensi[{}].{}".format(table_name, syntax.expression)
                                             settings_modif_express.append(expression)
                                             settings_modif_values.append(syntax.value)
+                                            
                                             log("Added {} to settings_modif".format(expression), self.logger)
                                         except syn.SensiSyntaxError:
                                             processed_sensi_messages[sensi_name] = SensiIOError("Unable to add {} to settings_modif because no table name is found in settings_json".format(syntax.expression))
+                                            log("Unable to add {} to settings_modif because no table name is found in settings_json".format(syntax.expression), self.logger)
 
                                         continue
                                 except syn.SensiSyntaxError as err:
                                     processed_sensi_messages[sensi_name] = SensiIOError(err.msg)
                                     log(processed_sensi_messages[sensi_name].msg, self.logger)
                                     break
-
+                            total_applied = total_applied+counter
+                        
                         # Saving settings_modif commands to settings_modif.csv
                         if len(settings_modif_express)>0 and len(settings_modif_values)>0:
+                            total_applied = total_applied + len(settings_modif_express)
                             settings_modif_pd = pd.DataFrame({"id": settings_modif_express, "value": settings_modif_values})
                             settings_modif_pd.to_csv(os.path.join(sensi_dirpath, 'resources/settings_modif.csv'), sep=";", index=False)
                             log(f"settings_modif.csv of {sensi_name} saved", self.logger)
+
+                        if not isinstance(processed_sensi_messages[sensi_name], SensiIOError):
+                            processed_sensi_messages[sensi_name] = "Applied {} modification(s) on {}".format(total_applied, sensi_name)
+                            log(processed_sensi_messages[sensi_name], self.logger)
                 else:
                     processed_sensi_messages[sensi_name] = SensiIOError("Sensitivity path does not exist")
+                    log(processed_sensi_messages[sensi_name].msg, self.logger)
 
         return processed_sensi_messages
