@@ -254,7 +254,7 @@ def select_from_dataframe(condition, operation, dataframe):
                 elif operation == "<":
                     dataframe = dataframe[selected.T.iloc[0] < values[0]]
                 else:
-                    raise SensiSyntaxError(" {} is an unsupported Operation!".format(operation))
+                    raise SensiSyntaxError("{} is an unsupported Operation!".format(operation))
 
                 return dataframe
 
@@ -287,45 +287,48 @@ def interpret_condition(condition, dataframe):
 
 
 def apply_value_to_selection(value, selected_dict):
+    applying_operation = False
     operation = None
 
     value = value.strip()
     value = value.strip('"')
-    cond1 = value.startswith("(") and value.endswith(")")
-    cond2 = not value.startswith("(") and not value.endswith(")")
-    if cond1 or cond2:
-        value = value.strip("()")
+
+    if value.startswith("(") and value.endswith(")"):
+        applying_operation = True
+    value = value.strip("()")
 
     if value:
-        if value[0] in ('+', '-', '*', '/'):
-            operation, value = value[0], value.split(value[0])[1]
+        if applying_operation and value[0] in ('+', '-', '*', '/'):
+            operation, value = value[0], value[1:]
         if value:
             try:
                 value = int(value)
             except ValueError:
                 try:
-                    value = float(value)
+                    value = float(value.replace(",", '.'))
                 except ValueError:
                     if value.lower() in ["true", "false"]:
                         value = value.lower() == "true"
                     else:
                         pass
-
         if operation:
-            if operation == '+':
-                for column in selected_dict.keys():
-                    selected_dict[column] = {k: v + value if not isinstance(value, (str)) and not isinstance(v, str) else value for k, v in selected_dict[column].items()}
-            elif operation == '-':
-                for column in selected_dict.keys():
-                    selected_dict[column] = {k: v - value if not isinstance(value, (str)) and not isinstance(v, str) else -value for k, v in selected_dict[column].items()}
-            elif operation == '*':
-                for column in selected_dict.keys():
-                    selected_dict[column] = {k: v * value if not isinstance(value, (str)) and not isinstance(v, str) else 0 for k, v in selected_dict[column].items()}
-            elif operation == '/':
-                for column in selected_dict.keys():
-                    selected_dict[column] = {k: v / value if not isinstance(value, (str)) and not isinstance(v, str) else 0 for k, v in selected_dict[column].items()}
-            else:
-                raise SensiSyntaxError(" {} is an unsupported Operation!".format(operation))
+            try:
+                if operation == '+':
+                    for column in selected_dict.keys():
+                        selected_dict[column] = {k: v + value if not isinstance(value, (str)) and not isinstance(v, str) else value for k, v in selected_dict[column].items()}
+                elif operation == '-':
+                    for column in selected_dict.keys():
+                        selected_dict[column] = {k: v - value if not isinstance(value, (str)) and not isinstance(v, str) else -value for k, v in selected_dict[column].items()}
+                elif operation == '*':
+                    for column in selected_dict.keys():
+                        selected_dict[column] = {k: v * value if not isinstance(value, (str)) and not isinstance(v, str) else 0 for k, v in selected_dict[column].items()}
+                elif operation == '/':
+                    for column in selected_dict.keys():
+                        selected_dict[column] = {k: v / value if not isinstance(value, (str)) and not isinstance(v, str) else 0 for k, v in selected_dict[column].items()}
+                else:
+                    raise SensiSyntaxError("{} is an unsupported Operation!".format(operation))
+            except TypeError as exc:
+                raise SensiSyntaxError("Could not execute operation '{}' of {} and {} because: {}".format(operation, value, selected_dict, exc))
 
         else:
             for column in selected_dict.keys():
